AndroidOptions class

Constructors

AndroidOptions({bool? allowUseOfLocationData, Duration? locationTimeout})
const

Properties

allowUseOfLocationData → bool?
When true, the SDK may collect location data. It is collected during each get, see locationTimeout. https://docs.fingerprint.com/docs/android-sdk
final
hashCode → int
The hash code for this object.
no setteroverride
locationTimeout → Duration?
How long identification may wait for a location fix. Must be at least 1 millisecond, checked on every platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override